@@ -2,6 +2,7 @@
 Boto3 client Paginator.
 """
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.service_name import ServiceName
@@ -22,18 +23,31 @@ class Paginator(ClassRecord):
     def __init__(
         self,
         name: str,
+        paginator_name: str,
         operation_name: str,
         service_name: ServiceName,
-        docstring: str = "",
     ):
         super().__init__(
             name=name,
-            docstring=docstring,
             bases=[TypeClass(Boto3Paginator, alias="Boto3Paginator")],
         )
         self.operation_name = operation_name
+        self.paginator_name = paginator_name
         self.service_name = service_name
 
+    @property
+    def boto3_doc_link(self) -> str:
+        return self.service_name.get_boto3_doc_link("Paginator", self.paginator_name)
+
+    @property
+    def docstring(self) -> str:
+        return (
+            "[Show boto3 documentation]"
+            f"({self.boto3_doc_link})"
+            "[Show boto3-stubs documentation]"
+            f"({self.service_name.get_doc_link('paginators', self.name)})"
+        )
+
     def get_client_method(self) -> Method:
         return Method(
             name="get_paginator",
