@@ -9,6 +9,7 @@ from mypy_boto3_builder.import_helpers.internal_import_record import InternalImp
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
 from mypy_boto3_builder.type_annotations.type import Type
 from mypy_boto3_builder.type_annotations.type_literal import TypeLiteral
+from mypy_boto3_builder.utils.strings import is_reserved
 
 
 class TypedDictAttribute:
@@ -54,13 +55,16 @@ class TypeTypedDict(FakeAnnotation):
         children: Iterable[TypedDictAttribute] = (),
         docstring: str = "",
         stringify: bool = False,
-        replace_with_dict: bool = False,
+        replace_with_dict: Iterable[str] = tuple(),
     ) -> None:
         self.name = name
         self.children = list(children)
         self.docstring = docstring
         self.stringify = stringify
-        self.replace_with_dict = replace_with_dict
+        self.replace_with_dict = set(replace_with_dict)
+
+    def get_sort_key(self) -> str:
+        return self.name
 
     def get_attribute(self, name: str) -> TypedDictAttribute:
         for child in self.children:
@@ -76,7 +80,7 @@ class TypeTypedDict(FakeAnnotation):
         Returns:
             A string with a valid type annotation.
         """
-        if self.replace_with_dict:
+        if parent_name in self.replace_with_dict:
             return Type.DictStrAny.render()
 
         if self.stringify:
@@ -103,7 +107,7 @@ class TypeTypedDict(FakeAnnotation):
             A set of type annotations.
         """
         if self.replace_with_dict:
-            return Type.DictStrAny.get_types()
+            return {self, *Type.DictStrAny.get_types()}
 
         return {self}
 
@@ -124,6 +128,12 @@ class TypeTypedDict(FakeAnnotation):
         """
         return True
 
+    def is_typed_dict(self) -> bool:
+        """
+        Always True as it is a TypedDict.
+        """
+        return True
+
     def render_class(self) -> str:
         """
         Render class-based definition for debugging.
@@ -202,37 +212,38 @@ class TypeTypedDict(FakeAnnotation):
 
         return result
 
-    def get_children_literals(self) -> Set[TypeLiteral]:
+    def get_children_literals(
+        self, processed: Iterable["TypeTypedDict"] = tuple()
+    ) -> Set[TypeLiteral]:
         result: Set[TypeLiteral] = set()
+        if self in processed:
+            return result
         children_types = self.get_children_types()
         for type_annotation in children_types:
             if isinstance(type_annotation, TypeLiteral):
                 result.add(type_annotation)
             if isinstance(type_annotation, TypeTypedDict):
-                result.update(type_annotation.get_children_literals())
+                result.update(type_annotation.get_children_literals((self, *processed)))
         return result
 
-    def replace_self_references(self) -> List[str]:
+    def replace_self_references(self) -> None:
         """
         Replace self refenrences with `Dict[str, Any]` to avoid circular dependencies.
-
-        Returns:
-            A list of replaced children names.
         """
-        result: List[str] = []
         for child in self.get_children_typed_dicts():
-            if child.replace_with_dict:
-                continue
             if child is self:
-                child.replace_with_dict = True
-                result.append(child.name)
+                child.replace_with_dict.add(self.name)
                 continue
             for sub_child in child.get_children_typed_dicts():
                 if sub_child.replace_with_dict:
                     continue
                 if sub_child is self:
-                    sub_child.replace_with_dict = True
-                    result.append(sub_child.name)
+                    sub_child.replace_with_dict.add(child.name)
                     continue
 
-        return result
+    @property
+    def requires_safe_render(self) -> bool:
+        """
+        Whether TypedDict has reserved words and has to be rendered safely.
+        """
+        return any(is_reserved(child.name) for child in self.children)
