@@ -10,6 +10,7 @@ from mypy_boto3_builder.constants import BOTO3_STUBS_STATIC_PATH
 from mypy_boto3_builder.structures.boto3_stubs_package import Boto3StubsPackage
 from mypy_boto3_builder.writers.utils import (
     blackify,
+    format_md,
     insert_md_toc,
     render_jinja2_template,
     sort_imports,
@@ -66,6 +67,9 @@ def write_boto3_stubs_package(
                 third_party=["boto3", "botocore", *[i.module_name for i in package.service_names]],
             )
             content = blackify(content, file_path)
+        if file_path.suffix == ".md":
+            content = insert_md_toc(content)
+            content = format_md(content)
         if not file_path.exists() or file_path.read_text() != content:
             modified_paths.append(file_path)
             file_path.write_text(content)
@@ -97,6 +101,7 @@ def write_boto3_stubs_docs(package: Boto3StubsPackage, output_path: Path) -> Lis
             package=package,
         )
         content = insert_md_toc(content)
+        content = format_md(content)
         if not file_path.exists() or file_path.read_text() != content:
             modified_paths.append(file_path)
             file_path.write_text(content)
