@@ -9,6 +9,7 @@ from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.structures.service_package import ServicePackage
 from mypy_boto3_builder.writers.utils import (
     blackify,
+    format_md,
     insert_md_toc,
     render_jinja2_template,
     sort_imports,
@@ -133,6 +134,9 @@ def write_service_package(
         if file_path.suffix in [".py", ".pyi"]:
             content = sort_imports(content, package.service_name.module_name, extension="pyi")
             content = blackify(content, file_path)
+        if file_path.suffix == ".md":
+            content = insert_md_toc(content)
+            content = format_md(content)
 
         if not file_path.exists() or file_path.read_text() != content:
             modified_paths.append(file_path)
@@ -175,6 +179,7 @@ def write_service_docs(package: ServicePackage, output_path: Path) -> List[Path]
             service_name=package.service_name,
         )
         content = insert_md_toc(content)
+        content = format_md(content)
         if not file_path.exists() or file_path.read_text() != content:
             modified_paths.append(file_path)
             file_path.write_text(content)
